naming
======

.. automodule:: deltona.naming
   :exclude-members: adjust_title
   :members:
   :show-inheritance:

.. autofunction:: adjust_title(words: str, modes: Iterable[Mode] = (Mode.English,), names: dict[str, str] = ..., *, disable_names: bool = False, ampersands: bool = False) -> str
